"""
Init of rabbit_clients package

"""

from rabbit_clients.clients.base import PublishMessage as publish_message, ConsumeMessage as consume_message
from rabbit_clients.clients.base import PublishMessage, ConsumeMessage
